Geth nqp: MasterDuke17++ created pull request #880:
Reduce $?CLASS lookups
00:39
00:42 timo left 00:55 kjp left 01:08 kjp joined 06:20 kjp left, hankache_ left, djinni` left, finanalyst left, apogee_ntv left, hankache_ joined, apogee_ntv joined 06:21 kjp joined, djinni` joined 06:24 kjp left, ShimmerFairy left, coleman left, Pixi left 06:25 ShimmerFairy joined, kjp joined, Pixi joined 06:27 finanalyst joined
Geth nqp/main: da5e7771dc | MasterDuke17++ (committed using GitHub Web editor) | src/QRegex/Cursor.nqp
Reduce $?CLASS lookups (#880)

Looking it up once and putting it in a local decreases the number of times it's looked up via MVM_frame_find_lexical_by_name. Oddly, my example
  `raku -e 'my %h; my $c = "rakudo/gen/moar/CORE.c.setting".IO; for ^1 { for $c.lines { %h{$0}++ if /^\s+(\d+)/ } }; say "$_.value():$_.key()" for %h.sort(*.value)'`
only sees a 2x reduction, when I would expect something like a 5x reduction.
06:33
06:42 coleman joined
Geth rakudo/main: e77aaaef81 | (Elizabeth Mattijsen)++ | tools/templates/NQP_REVISION
Bump NQP to get $?CLASS lookups fix, Masterduke++
07:15
rakudo/lizmat-81: bff083cf6c | (Elizabeth Mattijsen)++ | src/core.c/Any-iterable-methods.rakumod
Reduce bytecode size of .are

Remove the return constraint, it's clear from the code that it either returns True or a Failure
Sadly a "target has a :noinline instruction - ins: takeclosure" is still preventing it from being inlined. Couldn't figure out why.
08:06
rakudo: lizmat++ created pull request #6858:
Reduce bytecode size of .are
nqp/main: e5e5a905f1 | (Elizabeth Mattijsen)++ | src/QRegex/Cursor.nqp
Some more $?CLASS -> $CLASS shortcuts
09:05
rakudo/lizmat-81: fb90dafeb3 | (Elizabeth Mattijsen)++ | tools/templates/NQP_REVISION
Bump NQP for more $?CLASS fixups
09:56
lizmat argh
Geth rakudo/main: 50379ea28a | (Elizabeth Mattijsen)++ | tools/templates/NQP_REVISION
Bump NQP for more $?CLASS fixups
10:54 hankache joined 10:58 hankache_ left 11:41 Pixi left 11:58 Pixi joined
ShimmerFairy lizmat: created that issue on the array constructor arguments on rakudo's bug tracker. If that's not where you expected me to file the bug (say, you were thinking of it as a spec issue instead), just let me know. 12:06
lizmat thanks, github.com/rakudo/rakudo/issues/6859 is fine 12:07
12:43 hankache left 12:48 hankache joined 14:54 [Coke] left 16:51 [Coke] joined 18:05 samebchase left 18:33 MasterDuke joined 18:59 MasterDuke left
lizmat bisectable6: class Foo { has @.bar }; say Foo.new(|{:bar([1, 2, 3])}) 19:50
bisectable6 lizmat, Will bisect the whole range automagically because no endpoints were provided, hang tight
lizmat, ¦6c (105 commits): «Foo.new(bar => [[1, 2, 3],])␤» 19:51
lizmat, Nothing to bisect!
21:05 finanalyst left